About
=====

This Python library for symbolic mathematics is a fork of the `SymPy`_, started
by Sergey B Kirpichev, last regular `SymPy`_'s commit is :commit:`cbdd072` (22
Feb 2015).  The git history goes back to 2007.

The project was named after the Diophantus of Alexandria.  His
"Arithmetica" is one of the earliest known texts that use symbols in
equations.  "Diofant" is a transliteration of Диофант, from Russian.

License
-------

Unless stated otherwise, all files in the `Diofant`_ project are
licensed using the new BSD license:

.. include:: ../LICENSE.rst

.. _SymPy : https://www.sympy.org/
.. _Diofant : https://diofant.readthedocs.io/en/latest/
